# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import messages_pb2 as messages__pb2
import simulation_pb2 as simulation__pb2


class SimulationControllerStub(object):
    """仿真-离线编程模拟服务
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetPos = channel.unary_unary(
                '/robotc.SimulationController/SetPos',
                request_serializer=messages__pb2.JPose.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.EStop = channel.unary_unary(
                '/robotc.SimulationController/EStop',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.EStopRelease = channel.unary_unary(
                '/robotc.SimulationController/EStopRelease',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.Button = channel.unary_unary(
                '/robotc.SimulationController/Button',
                request_serializer=simulation__pb2.ButtonReq.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.SetDialgage = channel.unary_unary(
                '/robotc.SimulationController/SetDialgage',
                request_serializer=simulation__pb2.DialgageReq.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.SetRobotAI = channel.unary_unary(
                '/robotc.SimulationController/SetRobotAI',
                request_serializer=messages__pb2.AIO.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.SetRobotDI = channel.unary_unary(
                '/robotc.SimulationController/SetRobotDI',
                request_serializer=messages__pb2.DIO.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.SetFlangeDI = channel.unary_unary(
                '/robotc.SimulationController/SetFlangeDI',
                request_serializer=messages__pb2.DIO.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )
        self.ChangeRobotSpeed = channel.unary_unary(
                '/robotc.SimulationController/ChangeRobotSpeed',
                request_serializer=simulation__pb2.RobotSpeed.SerializeToString,
                response_deserializer=simulation__pb2.SimRes.FromString,
                )


class SimulationControllerServicer(object):
    """仿真-离线编程模拟服务
    """

    def SetPos(self, request, context):
        """设置仿真机器人关节角
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EStop(self, request, context):
        """硬件急停
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EStopRelease(self, request, context):
        """释放硬件急停开关
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Button(self, request, context):
        """按下按钮
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDialgage(self, request, context):
        """设置百分表值
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRobotAI(self, request, context):
        """设置模拟输入
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRobotDI(self, request, context):
        """设置数字输入
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFlangeDI(self, request, context):
        """设置法兰数字输入
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeRobotSpeed(self, request, context):
        """设置仿真机器人运行速度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SimulationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetPos': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPos,
                    request_deserializer=messages__pb2.JPose.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'EStop': grpc.unary_unary_rpc_method_handler(
                    servicer.EStop,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'EStopRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.EStopRelease,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'Button': grpc.unary_unary_rpc_method_handler(
                    servicer.Button,
                    request_deserializer=simulation__pb2.ButtonReq.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'SetDialgage': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDialgage,
                    request_deserializer=simulation__pb2.DialgageReq.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'SetRobotAI': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRobotAI,
                    request_deserializer=messages__pb2.AIO.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'SetRobotDI': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRobotDI,
                    request_deserializer=messages__pb2.DIO.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'SetFlangeDI': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFlangeDI,
                    request_deserializer=messages__pb2.DIO.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
            'ChangeRobotSpeed': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeRobotSpeed,
                    request_deserializer=simulation__pb2.RobotSpeed.FromString,
                    response_serializer=simulation__pb2.SimRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'robotc.SimulationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SimulationController(object):
    """仿真-离线编程模拟服务
    """

    @staticmethod
    def SetPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/SetPos',
            messages__pb2.JPose.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EStop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/EStop',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EStopRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/EStopRelease',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Button(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/Button',
            simulation__pb2.ButtonReq.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDialgage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/SetDialgage',
            simulation__pb2.DialgageReq.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRobotAI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/SetRobotAI',
            messages__pb2.AIO.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRobotDI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/SetRobotDI',
            messages__pb2.DIO.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFlangeDI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/SetFlangeDI',
            messages__pb2.DIO.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeRobotSpeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.SimulationController/ChangeRobotSpeed',
            simulation__pb2.RobotSpeed.SerializeToString,
            simulation__pb2.SimRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: os_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='os_server.proto',
  package='osserver',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fos_server.proto\x12\x08osserver\"\x12\n\x03Req\x12\x0b\n\x03req\x18\x01 \x01(\x05\"I\n\x02PR\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\n\n\x02rr\x18\x04 \x01(\x01\x12\n\n\x02rp\x18\x05 \x01(\x01\x12\n\n\x02ry\x18\x06 \x01(\x01\"\xb4\x01\n\x05Joint\x12\x12\n\ntargetPose\x18\x01 \x01(\x01\x12\x0f\n\x07targetV\x18\x02 \x01(\x01\x12\x0f\n\x07targetA\x18\x03 \x01(\x01\x12\x14\n\x0ctargetTorque\x18\x04 \x01(\x01\x12\x12\n\nactualPose\x18\x05 \x01(\x01\x12\x0f\n\x07\x61\x63tualV\x18\x06 \x01(\x01\x12\x0f\n\x07\x61\x63tualA\x18\x07 \x01(\x01\x12\x14\n\x0c\x61\x63tualTorque\x18\x08 \x01(\x01\x12\x13\n\x0btemperature\x18\t \x01(\x01\"\xa7\x01\n\x08RingData\x12\x1f\n\x06joints\x18\x01 \x03(\x0b\x32\x0f.osserver.Joint\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12 \n\ntargetPose\x18\x03 \x01(\x0b\x32\x0c.osserver.PR\x12 \n\nactualPose\x18\x04 \x01(\x0b\x32\x0c.osserver.PR\x12)\n\x07voltage\x18\x05 \x01(\x0b\x32\x18.osserver.CurrentVoltage\"N\n\x0e\x43urrentVoltage\x12\r\n\x05power\x18\x01 \x01(\x01\x12\x0c\n\x04\x66lan\x18\x02 \x01(\x01\x12\r\n\x05joint\x18\x03 \x03(\x01\x12\x10\n\x08io_power\x18\x04 \x01(\x01\x32>\n\x08OsServer\x12\x32\n\x0bgetRingData\x12\r.osserver.Req\x1a\x12.osserver.RingData0\x01\x62\x06proto3'
)




_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='osserver.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req', full_name='osserver.Req.req', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=47,
)


_PR = _descriptor.Descriptor(
  name='PR',
  full_name='osserver.PR',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='osserver.PR.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='osserver.PR.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='osserver.PR.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rr', full_name='osserver.PR.rr', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rp', full_name='osserver.PR.rp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ry', full_name='osserver.PR.ry', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=122,
)


_JOINT = _descriptor.Descriptor(
  name='Joint',
  full_name='osserver.Joint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetPose', full_name='osserver.Joint.targetPose', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetV', full_name='osserver.Joint.targetV', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetA', full_name='osserver.Joint.targetA', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='osserver.Joint.targetTorque', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPose', full_name='osserver.Joint.actualPose', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualV', full_name='osserver.Joint.actualV', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualA', full_name='osserver.Joint.actualA', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTorque', full_name='osserver.Joint.actualTorque', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='osserver.Joint.temperature', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=305,
)


_RINGDATA = _descriptor.Descriptor(
  name='RingData',
  full_name='osserver.RingData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='osserver.RingData.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num', full_name='osserver.RingData.num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPose', full_name='osserver.RingData.targetPose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPose', full_name='osserver.RingData.actualPose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='osserver.RingData.voltage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=475,
)


_CURRENTVOLTAGE = _descriptor.Descriptor(
  name='CurrentVoltage',
  full_name='osserver.CurrentVoltage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='power', full_name='osserver.CurrentVoltage.power', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flan', full_name='osserver.CurrentVoltage.flan', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint', full_name='osserver.CurrentVoltage.joint', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_power', full_name='osserver.CurrentVoltage.io_power', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=555,
)

_RINGDATA.fields_by_name['joints'].message_type = _JOINT
_RINGDATA.fields_by_name['targetPose'].message_type = _PR
_RINGDATA.fields_by_name['actualPose'].message_type = _PR
_RINGDATA.fields_by_name['voltage'].message_type = _CURRENTVOLTAGE
DESCRIPTOR.message_types_by_name['Req'] = _REQ
DESCRIPTOR.message_types_by_name['PR'] = _PR
DESCRIPTOR.message_types_by_name['Joint'] = _JOINT
DESCRIPTOR.message_types_by_name['RingData'] = _RINGDATA
DESCRIPTOR.message_types_by_name['CurrentVoltage'] = _CURRENTVOLTAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), {
  'DESCRIPTOR' : _REQ,
  '__module__' : 'os_server_pb2'
  # @@protoc_insertion_point(class_scope:osserver.Req)
  })
_sym_db.RegisterMessage(Req)

PR = _reflection.GeneratedProtocolMessageType('PR', (_message.Message,), {
  'DESCRIPTOR' : _PR,
  '__module__' : 'os_server_pb2'
  # @@protoc_insertion_point(class_scope:osserver.PR)
  })
_sym_db.RegisterMessage(PR)

Joint = _reflection.GeneratedProtocolMessageType('Joint', (_message.Message,), {
  'DESCRIPTOR' : _JOINT,
  '__module__' : 'os_server_pb2'
  # @@protoc_insertion_point(class_scope:osserver.Joint)
  })
_sym_db.RegisterMessage(Joint)

RingData = _reflection.GeneratedProtocolMessageType('RingData', (_message.Message,), {
  'DESCRIPTOR' : _RINGDATA,
  '__module__' : 'os_server_pb2'
  # @@protoc_insertion_point(class_scope:osserver.RingData)
  })
_sym_db.RegisterMessage(RingData)

CurrentVoltage = _reflection.GeneratedProtocolMessageType('CurrentVoltage', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTVOLTAGE,
  '__module__' : 'os_server_pb2'
  # @@protoc_insertion_point(class_scope:osserver.CurrentVoltage)
  })
_sym_db.RegisterMessage(CurrentVoltage)



_OSSERVER = _descriptor.ServiceDescriptor(
  name='OsServer',
  full_name='osserver.OsServer',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=557,
  serialized_end=619,
  methods=[
  _descriptor.MethodDescriptor(
    name='getRingData',
    full_name='osserver.OsServer.getRingData',
    index=0,
    containing_service=None,
    input_type=_REQ,
    output_type=_RINGDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OSSERVER)

DESCRIPTOR.services_by_name['OsServer'] = _OSSERVER

# @@protoc_insertion_point(module_scope)



from enum import Enum, unique
from .pb2 import messages_pb2 as msg
from .pb2 import robot_controller_pb2 as rc
from .pb2 import private_controller_pb2 as pc

class RobotState(Enum):
    '''机器人状态
    '''
    DISCONNECTED = 0  # 已断开连接
    ESTOP = 1         # 急停停止状态
    BOOTING = 2       # 启动中
    ROBOT_OFF = 3     # 电源关闭
    ROBOT_ON = 4      # 电源开启
    IDLE = 5          # 空闲中
    PAUSED = 6        # 暂停中
    RUNNING = 7       # 机器人运动运行中
    UPDATING = 8      # 更新固件中
    STARTING = 9      # 启动中
    STOPPING = 10     # 停止中
    TEACHING = 11     # 示教中
    STOP = 12         # 普通停止
    FINETUNING = 13   # 微调中

class TaskStatus(Enum):
    IDLE = 0 # 空闲
    RUNNING = 1 # 运行中
    PAUSED = 2 # 暂停
    SUCCESS = 3 # 运行完成
    STOPPED = 4 # 停止
    ABORTED = 5 # 异常终止

class IODeviceType(Enum):
    HOST = 0 # 主机箱
    FLANGE = 1 # 法兰
    GRIPPER = 2 # 手爪
    MODBUS_TCP = 3 # MODBUS/TCP
    # MODBUS_TCP6 = 4
    # MODBUS_RTU = 5


class CartesianPose:
    '''空间位置
    
    笛卡尔坐标描述的位姿
    '''
    def __init__(self, x=0, y=0, z=0, rz=0, ry=0, rx=0, base=None):
        # print(x, hasattr(x, '__iter__'), hasattr(x, '__iter__'), type(x))
        if type(x) is msg.PR:
            self.pos = (x.position.x, x.position.y, x.position.z, x.rotation.r, x.rotation.p, x.rotation.y)
        elif hasattr(x, 'pos'):
            self.pos = x.pos[:]
            if hasattr(x, 'base'):
                base = x.base
        elif hasattr(x, '__iter__') or type(x) is list:
            self.pos = tuple(x)
        else:
            self.pos = (x, y, z, rz, ry, rx)
        self.is_joint = False
        # 要求 base 是元组或列表而不是 CartesianPose 对象
        self.base = getattr(base, 'pos', base) if base is not None else None

    def __str__(self):
        if self.base is None:
            return 'CartesianPose' + str(self.pos)
        else:
            return f'CartesianPose({self.pos[0]}, {self.pos[1]}, {self.pos[2]}, {self.pos[3]}, {self.pos[4]}, {self.pos[5]}, base={self.base})'

    def __getattr__(self, key):
        pos_idx_arr = ['x', 'y', 'z', 'rz', 'ry', 'rx']
        if key in pos_idx_arr:
            idx = pos_idx_arr.index(key)
            return getattr(self, 'pos')[idx]
        else:
            return getattr(self, key)

    def __eq__(self, other):
        return self.pos == other.pos and self.base == other.base

    def _to_PR(self):
        p = msg.Coordinate(x=self.pos[0], y=self.pos[1], z=self.pos[2])
        r = msg.Rotation(r=self.pos[3], p=self.pos[4], y=self.pos[5])
        return msg.PR(position=p,rotation=r)

    def _base_set_PR(self, pr):
        if self.base is not None:
            pr.position.x = self.base[0]
            pr.position.y = self.base[1]
            pr.position.z = self.base[2]
            pr.rotation.r = self.base[3]
            pr.rotation.p = self.base[4]
            pr.rotation.y = self.base[5]
    
    def _to_Vector(self):
        return rc.Vector(vector=self.pos)

class JointPose:
    '''关节位置
    
    关节旋转角度描述的机器人姿态
    '''
    def __init__(self, *j):
        if hasattr(j[0], 'pos'):
            self.pos = j[0].pos
        elif hasattr(j[0], '__iter__'):
            self.pos = tuple(j[0])
        else:
            self.pos = j
        self.is_joint = True

    def __str__(self):
        return 'JointPose' + str(self.pos)
    
    def _to_Joint(self):
        return rc.Joint(joints=self.pos)

class Error(Exception):
    """Base class for exceptions in this module."""
    pass

class RequestError(Error):
    def __init__(self, res):
        print(res)
        self.code = getattr(res, 'code', -1)
        self.param = getattr(res, 'msg_params', [])
        self.data = getattr(res, 'data', None)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import messages_pb2 as messages__pb2
from . import private_controller_pb2 as private__controller__pb2


class RobotPrivateControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
                '/robotc.RobotPrivateController/Init',
                request_serializer=private__controller__pb2.Configuration.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.GetRobotInfo = channel.unary_unary(
                '/robotc.RobotPrivateController/GetRobotInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=messages__pb2.RobotInfo.FromString,
                )
        self.SetInstallDirection = channel.unary_unary(
                '/robotc.RobotPrivateController/SetInstallDirection',
                request_serializer=private__controller__pb2.InstallDirection.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetCollisionDetector = channel.unary_unary(
                '/robotc.RobotPrivateController/SetCollisionDetector',
                request_serializer=private__controller__pb2.CollisionDetector.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetJointConfig = channel.unary_unary(
                '/robotc.RobotPrivateController/SetJointConfig',
                request_serializer=private__controller__pb2.JointConfigs.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetCartesianConfig = channel.unary_unary(
                '/robotc.RobotPrivateController/SetCartesianConfig',
                request_serializer=private__controller__pb2.CartesianConfig.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.EnableDDS = channel.unary_unary(
                '/robotc.RobotPrivateController/EnableDDS',
                request_serializer=private__controller__pb2.TrueOrFalse.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetCollisionTorqueDiff = channel.unary_unary(
                '/robotc.RobotPrivateController/SetCollisionTorqueDiff',
                request_serializer=private__controller__pb2.CollisionTorqueDiff.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.RegisterNotification = channel.unary_stream(
                '/robotc.RobotPrivateController/RegisterNotification',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.Notification.FromString,
                )
        self.RobotDriverInfo = channel.unary_unary(
                '/robotc.RobotPrivateController/RobotDriverInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.DriverInfo.FromString,
                )
        self.RobotOTA = channel.unary_stream(
                '/robotc.RobotPrivateController/RobotOTA',
                request_serializer=private__controller__pb2.OTAData.SerializeToString,
                response_deserializer=private__controller__pb2.OTAResult.FromString,
                )
        self.SwitchOtaPartition = channel.unary_unary(
                '/robotc.RobotPrivateController/SwitchOtaPartition',
                request_serializer=private__controller__pb2.OTACmd.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.RobotOTABatch = channel.unary_stream(
                '/robotc.RobotPrivateController/RobotOTABatch',
                request_serializer=private__controller__pb2.OTADatas.SerializeToString,
                response_deserializer=private__controller__pb2.OTAResults.FromString,
                )
        self.Reset = channel.unary_unary(
                '/robotc.RobotPrivateController/Reset',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.InitZero = channel.unary_unary(
                '/robotc.RobotPrivateController/InitZero',
                request_serializer=private__controller__pb2.Zero.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetZero = channel.unary_unary(
                '/robotc.RobotPrivateController/SetZero',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.GetVoltage = channel.unary_unary(
                '/robotc.RobotPrivateController/GetVoltage',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.CurrentVoltage.FromString,
                )
        self.SetServoParam = channel.unary_unary(
                '/robotc.RobotPrivateController/SetServoParam',
                request_serializer=private__controller__pb2.JointServoParam.SerializeToString,
                response_deserializer=private__controller__pb2.JointServoParams.FromString,
                )
        self.GetServoParams = channel.unary_unary(
                '/robotc.RobotPrivateController/GetServoParams',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.JointServoParams.FromString,
                )
        self.SetDebugParams = channel.unary_unary(
                '/robotc.RobotPrivateController/SetDebugParams',
                request_serializer=private__controller__pb2.DebugParams.SerializeToString,
                response_deserializer=private__controller__pb2.DebugParams.FromString,
                )
        self.FixDHParams = channel.unary_unary(
                '/robotc.RobotPrivateController/FixDHParams',
                request_serializer=private__controller__pb2.FixDHRequest.SerializeToString,
                response_deserializer=private__controller__pb2.FixDHResult.FromString,
                )
        self.SetLEDStyle = channel.unary_unary(
                '/robotc.RobotPrivateController/SetLEDStyle',
                request_serializer=private__controller__pb2.LEDStyle.SerializeToString,
                response_deserializer=private__controller__pb2.LEDStyles.FromString,
                )
        self.GetLEDStyles = channel.unary_unary(
                '/robotc.RobotPrivateController/GetLEDStyles',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.LEDStyles.FromString,
                )
        self.RegisterLuaEvent = channel.unary_stream(
                '/robotc.RobotPrivateController/RegisterLuaEvent',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.LuaEvent.FromString,
                )
        self.ConfirmCallback = channel.unary_unary(
                '/robotc.RobotPrivateController/ConfirmCallback',
                request_serializer=private__controller__pb2.ConfirmInput.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.GetLastPose = channel.unary_unary(
                '/robotc.RobotPrivateController/GetLastPose',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.PoseRes.FromString,
                )
        self.SetModbusExternalIO = channel.unary_unary(
                '/robotc.RobotPrivateController/SetModbusExternalIO',
                request_serializer=private__controller__pb2.ModbusExternalIOs.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetButtonConfig = channel.unary_unary(
                '/robotc.RobotPrivateController/SetButtonConfig',
                request_serializer=private__controller__pb2.ButtonConfig.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.SetBreakACup = channel.unary_unary(
                '/robotc.RobotPrivateController/SetBreakACup',
                request_serializer=private__controller__pb2.TrueOrFalse.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.RecordPVAT = channel.unary_stream(
                '/robotc.RobotPrivateController/RecordPVAT',
                request_serializer=private__controller__pb2.RecordPVATRequest.SerializeToString,
                response_deserializer=private__controller__pb2.RecordPVATResponse.FromString,
                )
        self.StopRecordPVAT = channel.unary_unary(
                '/robotc.RobotPrivateController/StopRecordPVAT',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )
        self.UpgradeVoiceFile = channel.unary_stream(
                '/robotc.RobotPrivateController/UpgradeVoiceFile',
                request_serializer=private__controller__pb2.VoiceFile.SerializeToString,
                response_deserializer=private__controller__pb2.VoiceResult.FromString,
                )
        self.GetDHParams = channel.unary_unary(
                '/robotc.RobotPrivateController/GetDHParams',
                request_serializer=private__controller__pb2.DHRequest.SerializeToString,
                response_deserializer=private__controller__pb2.DHParams.FromString,
                )
        self.SetDHParams = channel.unary_unary(
                '/robotc.RobotPrivateController/SetDHParams',
                request_serializer=private__controller__pb2.DHParams.SerializeToString,
                response_deserializer=private__controller__pb2.DHParams.FromString,
                )
        self.WriteExtraServoParam = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteExtraServoParam',
                request_serializer=private__controller__pb2.ExtraServoParam.SerializeToString,
                response_deserializer=private__controller__pb2.ExtraServoParam.FromString,
                )
        self.ReadExtraServoParam = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadExtraServoParam',
                request_serializer=private__controller__pb2.ExtraServoParam.SerializeToString,
                response_deserializer=private__controller__pb2.ExtraServoParam.FromString,
                )
        self.WriteExtraServoParams = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteExtraServoParams',
                request_serializer=private__controller__pb2.ExtraServoParam.SerializeToString,
                response_deserializer=private__controller__pb2.ExtraServoParams.FromString,
                )
        self.ReadExtraServoParams = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadExtraServoParams',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.ExtraServoParams.FromString,
                )
        self.ResetExtraServoParams = channel.unary_unary(
                '/robotc.RobotPrivateController/ResetExtraServoParams',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.ExtraServoParams.FromString,
                )
        self.WriteJointBacklash = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteJointBacklash',
                request_serializer=private__controller__pb2.JointBacklash.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklash.FromString,
                )
        self.ReadJointBacklash = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadJointBacklash',
                request_serializer=private__controller__pb2.JointBacklash.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklash.FromString,
                )
        self.WriteJointBacklashes = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteJointBacklashes',
                request_serializer=private__controller__pb2.JointBacklash.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashes.FromString,
                )
        self.ReadJointBacklashes = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadJointBacklashes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashes.FromString,
                )
        self.ResetJointBacklashes = channel.unary_unary(
                '/robotc.RobotPrivateController/ResetJointBacklashes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashes.FromString,
                )
        self.WriteEnableJointBacklashes = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteEnableJointBacklashes',
                request_serializer=private__controller__pb2.EnableJointBacklash.SerializeToString,
                response_deserializer=private__controller__pb2.EnableJointBacklashes.FromString,
                )
        self.ReadEnableJointBacklashes = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadEnableJointBacklashes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.EnableJointBacklashes.FromString,
                )
        self.ResetEnableJointBacklashes = channel.unary_unary(
                '/robotc.RobotPrivateController/ResetEnableJointBacklashes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.EnableJointBacklashes.FromString,
                )
        self.WriteJointBacklashParam = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteJointBacklashParam',
                request_serializer=private__controller__pb2.JointBacklashParam.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashParam.FromString,
                )
        self.ReadJointBacklashParam = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadJointBacklashParam',
                request_serializer=private__controller__pb2.JointBacklashParam.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashParam.FromString,
                )
        self.WriteJointBacklashParams = channel.unary_unary(
                '/robotc.RobotPrivateController/WriteJointBacklashParams',
                request_serializer=private__controller__pb2.JointBacklashParam.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashParams.FromString,
                )
        self.ReadJointBacklashParams = channel.unary_unary(
                '/robotc.RobotPrivateController/ReadJointBacklashParams',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashParams.FromString,
                )
        self.ResetJointBacklashParams = channel.unary_unary(
                '/robotc.RobotPrivateController/ResetJointBacklashParams',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=private__controller__pb2.JointBacklashParams.FromString,
                )
        self.EnableJointLimit = channel.unary_unary(
                '/robotc.RobotPrivateController/EnableJointLimit',
                request_serializer=private__controller__pb2.TrueOrFalse.SerializeToString,
                response_deserializer=messages__pb2.Response.FromString,
                )


class RobotPrivateControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """初始化配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRobotInfo(self, request, context):
        """获取机器人基础信息
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetInstallDirection(self, request, context):
        """设置机器人安装方向
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollisionDetector(self, request, context):
        """设置碰撞检测
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetJointConfig(self, request, context):
        """设置关节配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCartesianConfig(self, request, context):
        """设置笛卡尔空间的配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDDS(self, request, context):
        """开启DDS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollisionTorqueDiff(self, request, context):
        """设置碰撞检测力矩差阈值
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterNotification(self, request, context):
        """注册通知事件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RobotDriverInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RobotOTA(self, request, context):
        """机器人OTA单个设备更新接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SwitchOtaPartition(self, request, context):
        """通知灯板、法兰、关节切换分区
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RobotOTABatch(self, request, context):
        """机器人OTA批量更新接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reset(self, request, context):
        """重置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitZero(self, request, context):
        """以给定角度置零
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetZero(self, request, context):
        """以零位置零
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVoltage(self, request, context):
        """获取机器人电压V
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetServoParam(self, request, context):
        """设置单关节伺服参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServoParams(self, request, context):
        """获取当前所有关节伺服参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDebugParams(self, request, context):
        """调试设置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FixDHParams(self, request, context):
        """更改DH参数（三轴平行6参数）
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLEDStyle(self, request, context):
        """设置LED样式
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLEDStyles(self, request, context):
        """获取LED样式
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterLuaEvent(self, request, context):
        """注册命令状态事件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmCallback(self, request, context):
        """当推送 ALERT/CONFIRM/INPUT/SELECT，用户在前端确定后调用该接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLastPose(self, request, context):
        """获取 Lua 上次执行到的机器人位置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetModbusExternalIO(self, request, context):
        """配置Modbus外部IO设备
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetButtonConfig(self, request, context):
        """修改按钮配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBreakACup(self, request, context):
        """设置绑定设备开关, true: 不限制设备绑定； false：限制设备绑定逻辑
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordPVAT(self, request, context):
        """PVAT数据记录接口，用户记录pvat数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopRecordPVAT(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradeVoiceFile(self, request, context):
        """语音升级
        yvoice
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDHParams(self, request, context):
        """获取当前 DH 参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDHParams(self, request, context):
        """设置 DH 参数并返回设置后的结果
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteExtraServoParam(self, request, context):
        """伺服控制参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadExtraServoParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteExtraServoParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadExtraServoParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetExtraServoParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteJointBacklash(self, request, context):
        """“主动消回差”参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadJointBacklash(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteJointBacklashes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadJointBacklashes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetJointBacklashes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteEnableJointBacklashes(self, request, context):
        """启用主动消回差
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadEnableJointBacklashes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetEnableJointBacklashes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteJointBacklashParam(self, request, context):
        """关节回差参数
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadJointBacklashParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteJointBacklashParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadJointBacklashParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetJointBacklashParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableJointLimit(self, request, context):
        """关节限位检测
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RobotPrivateControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Init': grpc.unary_unary_rpc_method_handler(
                    servicer.Init,
                    request_deserializer=private__controller__pb2.Configuration.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'GetRobotInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRobotInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=messages__pb2.RobotInfo.SerializeToString,
            ),
            'SetInstallDirection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetInstallDirection,
                    request_deserializer=private__controller__pb2.InstallDirection.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetCollisionDetector': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollisionDetector,
                    request_deserializer=private__controller__pb2.CollisionDetector.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetJointConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetJointConfig,
                    request_deserializer=private__controller__pb2.JointConfigs.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetCartesianConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCartesianConfig,
                    request_deserializer=private__controller__pb2.CartesianConfig.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'EnableDDS': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDDS,
                    request_deserializer=private__controller__pb2.TrueOrFalse.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetCollisionTorqueDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollisionTorqueDiff,
                    request_deserializer=private__controller__pb2.CollisionTorqueDiff.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'RegisterNotification': grpc.unary_stream_rpc_method_handler(
                    servicer.RegisterNotification,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.Notification.SerializeToString,
            ),
            'RobotDriverInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.RobotDriverInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.DriverInfo.SerializeToString,
            ),
            'RobotOTA': grpc.unary_stream_rpc_method_handler(
                    servicer.RobotOTA,
                    request_deserializer=private__controller__pb2.OTAData.FromString,
                    response_serializer=private__controller__pb2.OTAResult.SerializeToString,
            ),
            'SwitchOtaPartition': grpc.unary_unary_rpc_method_handler(
                    servicer.SwitchOtaPartition,
                    request_deserializer=private__controller__pb2.OTACmd.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'RobotOTABatch': grpc.unary_stream_rpc_method_handler(
                    servicer.RobotOTABatch,
                    request_deserializer=private__controller__pb2.OTADatas.FromString,
                    response_serializer=private__controller__pb2.OTAResults.SerializeToString,
            ),
            'Reset': grpc.unary_unary_rpc_method_handler(
                    servicer.Reset,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'InitZero': grpc.unary_unary_rpc_method_handler(
                    servicer.InitZero,
                    request_deserializer=private__controller__pb2.Zero.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetZero': grpc.unary_unary_rpc_method_handler(
                    servicer.SetZero,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'GetVoltage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVoltage,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.CurrentVoltage.SerializeToString,
            ),
            'SetServoParam': grpc.unary_unary_rpc_method_handler(
                    servicer.SetServoParam,
                    request_deserializer=private__controller__pb2.JointServoParam.FromString,
                    response_serializer=private__controller__pb2.JointServoParams.SerializeToString,
            ),
            'GetServoParams': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServoParams,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.JointServoParams.SerializeToString,
            ),
            'SetDebugParams': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDebugParams,
                    request_deserializer=private__controller__pb2.DebugParams.FromString,
                    response_serializer=private__controller__pb2.DebugParams.SerializeToString,
            ),
            'FixDHParams': grpc.unary_unary_rpc_method_handler(
                    servicer.FixDHParams,
                    request_deserializer=private__controller__pb2.FixDHRequest.FromString,
                    response_serializer=private__controller__pb2.FixDHResult.SerializeToString,
            ),
            'SetLEDStyle': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLEDStyle,
                    request_deserializer=private__controller__pb2.LEDStyle.FromString,
                    response_serializer=private__controller__pb2.LEDStyles.SerializeToString,
            ),
            'GetLEDStyles': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLEDStyles,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.LEDStyles.SerializeToString,
            ),
            'RegisterLuaEvent': grpc.unary_stream_rpc_method_handler(
                    servicer.RegisterLuaEvent,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.LuaEvent.SerializeToString,
            ),
            'ConfirmCallback': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmCallback,
                    request_deserializer=private__controller__pb2.ConfirmInput.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'GetLastPose': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLastPose,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.PoseRes.SerializeToString,
            ),
            'SetModbusExternalIO': grpc.unary_unary_rpc_method_handler(
                    servicer.SetModbusExternalIO,
                    request_deserializer=private__controller__pb2.ModbusExternalIOs.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetButtonConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetButtonConfig,
                    request_deserializer=private__controller__pb2.ButtonConfig.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'SetBreakACup': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBreakACup,
                    request_deserializer=private__controller__pb2.TrueOrFalse.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'RecordPVAT': grpc.unary_stream_rpc_method_handler(
                    servicer.RecordPVAT,
                    request_deserializer=private__controller__pb2.RecordPVATRequest.FromString,
                    response_serializer=private__controller__pb2.RecordPVATResponse.SerializeToString,
            ),
            'StopRecordPVAT': grpc.unary_unary_rpc_method_handler(
                    servicer.StopRecordPVAT,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
            'UpgradeVoiceFile': grpc.unary_stream_rpc_method_handler(
                    servicer.UpgradeVoiceFile,
                    request_deserializer=private__controller__pb2.VoiceFile.FromString,
                    response_serializer=private__controller__pb2.VoiceResult.SerializeToString,
            ),
            'GetDHParams': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDHParams,
                    request_deserializer=private__controller__pb2.DHRequest.FromString,
                    response_serializer=private__controller__pb2.DHParams.SerializeToString,
            ),
            'SetDHParams': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDHParams,
                    request_deserializer=private__controller__pb2.DHParams.FromString,
                    response_serializer=private__controller__pb2.DHParams.SerializeToString,
            ),
            'WriteExtraServoParam': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteExtraServoParam,
                    request_deserializer=private__controller__pb2.ExtraServoParam.FromString,
                    response_serializer=private__controller__pb2.ExtraServoParam.SerializeToString,
            ),
            'ReadExtraServoParam': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadExtraServoParam,
                    request_deserializer=private__controller__pb2.ExtraServoParam.FromString,
                    response_serializer=private__controller__pb2.ExtraServoParam.SerializeToString,
            ),
            'WriteExtraServoParams': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteExtraServoParams,
                    request_deserializer=private__controller__pb2.ExtraServoParam.FromString,
                    response_serializer=private__controller__pb2.ExtraServoParams.SerializeToString,
            ),
            'ReadExtraServoParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadExtraServoParams,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.ExtraServoParams.SerializeToString,
            ),
            'ResetExtraServoParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetExtraServoParams,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.ExtraServoParams.SerializeToString,
            ),
            'WriteJointBacklash': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteJointBacklash,
                    request_deserializer=private__controller__pb2.JointBacklash.FromString,
                    response_serializer=private__controller__pb2.JointBacklash.SerializeToString,
            ),
            'ReadJointBacklash': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadJointBacklash,
                    request_deserializer=private__controller__pb2.JointBacklash.FromString,
                    response_serializer=private__controller__pb2.JointBacklash.SerializeToString,
            ),
            'WriteJointBacklashes': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteJointBacklashes,
                    request_deserializer=private__controller__pb2.JointBacklash.FromString,
                    response_serializer=private__controller__pb2.JointBacklashes.SerializeToString,
            ),
            'ReadJointBacklashes': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadJointBacklashes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.JointBacklashes.SerializeToString,
            ),
            'ResetJointBacklashes': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetJointBacklashes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.JointBacklashes.SerializeToString,
            ),
            'WriteEnableJointBacklashes': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteEnableJointBacklashes,
                    request_deserializer=private__controller__pb2.EnableJointBacklash.FromString,
                    response_serializer=private__controller__pb2.EnableJointBacklashes.SerializeToString,
            ),
            'ReadEnableJointBacklashes': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadEnableJointBacklashes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.EnableJointBacklashes.SerializeToString,
            ),
            'ResetEnableJointBacklashes': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetEnableJointBacklashes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.EnableJointBacklashes.SerializeToString,
            ),
            'WriteJointBacklashParam': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteJointBacklashParam,
                    request_deserializer=private__controller__pb2.JointBacklashParam.FromString,
                    response_serializer=private__controller__pb2.JointBacklashParam.SerializeToString,
            ),
            'ReadJointBacklashParam': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadJointBacklashParam,
                    request_deserializer=private__controller__pb2.JointBacklashParam.FromString,
                    response_serializer=private__controller__pb2.JointBacklashParam.SerializeToString,
            ),
            'WriteJointBacklashParams': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteJointBacklashParams,
                    request_deserializer=private__controller__pb2.JointBacklashParam.FromString,
                    response_serializer=private__controller__pb2.JointBacklashParams.SerializeToString,
            ),
            'ReadJointBacklashParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadJointBacklashParams,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.JointBacklashParams.SerializeToString,
            ),
            'ResetJointBacklashParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetJointBacklashParams,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=private__controller__pb2.JointBacklashParams.SerializeToString,
            ),
            'EnableJointLimit': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableJointLimit,
                    request_deserializer=private__controller__pb2.TrueOrFalse.FromString,
                    response_serializer=messages__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'robotc.RobotPrivateController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RobotPrivateController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/Init',
            private__controller__pb2.Configuration.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRobotInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/GetRobotInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            messages__pb2.RobotInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetInstallDirection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetInstallDirection',
            private__controller__pb2.InstallDirection.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollisionDetector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetCollisionDetector',
            private__controller__pb2.CollisionDetector.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetJointConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetJointConfig',
            private__controller__pb2.JointConfigs.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCartesianConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetCartesianConfig',
            private__controller__pb2.CartesianConfig.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/EnableDDS',
            private__controller__pb2.TrueOrFalse.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollisionTorqueDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetCollisionTorqueDiff',
            private__controller__pb2.CollisionTorqueDiff.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/robotc.RobotPrivateController/RegisterNotification',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.Notification.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RobotDriverInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/RobotDriverInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.DriverInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RobotOTA(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/robotc.RobotPrivateController/RobotOTA',
            private__controller__pb2.OTAData.SerializeToString,
            private__controller__pb2.OTAResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SwitchOtaPartition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SwitchOtaPartition',
            private__controller__pb2.OTACmd.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RobotOTABatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/robotc.RobotPrivateController/RobotOTABatch',
            private__controller__pb2.OTADatas.SerializeToString,
            private__controller__pb2.OTAResults.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/Reset',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitZero(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/InitZero',
            private__controller__pb2.Zero.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetZero(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetZero',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVoltage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/GetVoltage',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.CurrentVoltage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetServoParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetServoParam',
            private__controller__pb2.JointServoParam.SerializeToString,
            private__controller__pb2.JointServoParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServoParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/GetServoParams',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.JointServoParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDebugParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetDebugParams',
            private__controller__pb2.DebugParams.SerializeToString,
            private__controller__pb2.DebugParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FixDHParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/FixDHParams',
            private__controller__pb2.FixDHRequest.SerializeToString,
            private__controller__pb2.FixDHResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetLEDStyle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetLEDStyle',
            private__controller__pb2.LEDStyle.SerializeToString,
            private__controller__pb2.LEDStyles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLEDStyles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/GetLEDStyles',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.LEDStyles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterLuaEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/robotc.RobotPrivateController/RegisterLuaEvent',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.LuaEvent.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmCallback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ConfirmCallback',
            private__controller__pb2.ConfirmInput.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLastPose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/GetLastPose',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.PoseRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetModbusExternalIO(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetModbusExternalIO',
            private__controller__pb2.ModbusExternalIOs.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetButtonConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetButtonConfig',
            private__controller__pb2.ButtonConfig.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetBreakACup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetBreakACup',
            private__controller__pb2.TrueOrFalse.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordPVAT(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/robotc.RobotPrivateController/RecordPVAT',
            private__controller__pb2.RecordPVATRequest.SerializeToString,
            private__controller__pb2.RecordPVATResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopRecordPVAT(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/StopRecordPVAT',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpgradeVoiceFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/robotc.RobotPrivateController/UpgradeVoiceFile',
            private__controller__pb2.VoiceFile.SerializeToString,
            private__controller__pb2.VoiceResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDHParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/GetDHParams',
            private__controller__pb2.DHRequest.SerializeToString,
            private__controller__pb2.DHParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDHParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/SetDHParams',
            private__controller__pb2.DHParams.SerializeToString,
            private__controller__pb2.DHParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteExtraServoParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteExtraServoParam',
            private__controller__pb2.ExtraServoParam.SerializeToString,
            private__controller__pb2.ExtraServoParam.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadExtraServoParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadExtraServoParam',
            private__controller__pb2.ExtraServoParam.SerializeToString,
            private__controller__pb2.ExtraServoParam.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteExtraServoParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteExtraServoParams',
            private__controller__pb2.ExtraServoParam.SerializeToString,
            private__controller__pb2.ExtraServoParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadExtraServoParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadExtraServoParams',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.ExtraServoParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetExtraServoParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ResetExtraServoParams',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.ExtraServoParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteJointBacklash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteJointBacklash',
            private__controller__pb2.JointBacklash.SerializeToString,
            private__controller__pb2.JointBacklash.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadJointBacklash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadJointBacklash',
            private__controller__pb2.JointBacklash.SerializeToString,
            private__controller__pb2.JointBacklash.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteJointBacklashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteJointBacklashes',
            private__controller__pb2.JointBacklash.SerializeToString,
            private__controller__pb2.JointBacklashes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadJointBacklashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadJointBacklashes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.JointBacklashes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetJointBacklashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ResetJointBacklashes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.JointBacklashes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteEnableJointBacklashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteEnableJointBacklashes',
            private__controller__pb2.EnableJointBacklash.SerializeToString,
            private__controller__pb2.EnableJointBacklashes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadEnableJointBacklashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadEnableJointBacklashes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.EnableJointBacklashes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetEnableJointBacklashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ResetEnableJointBacklashes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.EnableJointBacklashes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteJointBacklashParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteJointBacklashParam',
            private__controller__pb2.JointBacklashParam.SerializeToString,
            private__controller__pb2.JointBacklashParam.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadJointBacklashParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadJointBacklashParam',
            private__controller__pb2.JointBacklashParam.SerializeToString,
            private__controller__pb2.JointBacklashParam.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteJointBacklashParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/WriteJointBacklashParams',
            private__controller__pb2.JointBacklashParam.SerializeToString,
            private__controller__pb2.JointBacklashParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadJointBacklashParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ReadJointBacklashParams',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.JointBacklashParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetJointBacklashParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/ResetJointBacklashParams',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            private__controller__pb2.JointBacklashParams.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableJointLimit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/robotc.RobotPrivateController/EnableJointLimit',
            private__controller__pb2.TrueOrFalse.SerializeToString,
            messages__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import requests
import json
import time
import socket

from .type import *

class LebaiScene:
    def __init__(self, ip, scene_id=0, task_id=0):
        self.ip = ip
        self.scene_id = scene_id
        self.task_id = task_id
        self.robot = LebaiRobot(ip)

    def start(self, loop=1, force=False):
        payload = {
            'execute_count': loop,
            'clear': 1 if force else 0
        }
        if self.task_id > 0:
            payload['task_id'] = self.task_id
        else:
            payload['scene_id'] = self.scene_id
        payload = json.dumps(payload)
        r = requests.post("http://{0}/public/task".format(self.ip), data=payload)
        r.raise_for_status()
        r = r.json()
        if r['code'] == 0:
            self.task_id = r['data']['id']
        else:
            raise RequestError(r)

    def pause(self):
        self.robot.action('pause_task', sleep=1)

    def resume(self):
        self.robot.action('resume_task', sleep=1)

    def stop(self):
        self.robot.action('stop_task', sleep=1)
    
    def result(self):
        r = requests.get("http://{0}/public/task".format(self.ip), params={'id': self.task_id})
        r.raise_for_status()
        r = r.json()
        if r['code'] == 0:
            return r['data']
        else:
            raise RequestError(r)

    def status(self):
        return TaskStatus(self.result()['status'])

    def done(self):
        status = self.status()
        if status == TaskStatus.SUCCESS or status == TaskStatus.STOPPED or status == TaskStatus.ABORTED:
            return True
        return False

    def run(self, loop=1):
        output = b''
        self.start(loop, True)
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((self.ip, 5180))
            while True:
                output += s.recv(1024)
                if self.done():
                    break
        return output.decode('utf-8')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: simulation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='simulation.proto',
  package='robotc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10simulation.proto\x12\x06robotc\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0emessages.proto\"\x15\n\x06SimRes\x12\x0b\n\x03ret\x18\x01 \x01(\x05\"&\n\tButtonReq\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x05\"(\n\x0b\x44ialgageReq\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\x1b\n\nRobotSpeed\x12\r\n\x05\x63ycle\x18\x01 \x01(\r2\xc3\x03\n\x14SimulationController\x12\'\n\x06SetPos\x12\r.robotc.JPose\x1a\x0e.robotc.SimRes\x12/\n\x05\x45Stop\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.SimRes\x12\x36\n\x0c\x45StopRelease\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.SimRes\x12+\n\x06\x42utton\x12\x11.robotc.ButtonReq\x1a\x0e.robotc.SimRes\x12\x32\n\x0bSetDialgage\x12\x13.robotc.DialgageReq\x1a\x0e.robotc.SimRes\x12)\n\nSetRobotAI\x12\x0b.robotc.AIO\x1a\x0e.robotc.SimRes\x12)\n\nSetRobotDI\x12\x0b.robotc.DIO\x1a\x0e.robotc.SimRes\x12*\n\x0bSetFlangeDI\x12\x0b.robotc.DIO\x1a\x0e.robotc.SimRes\x12\x36\n\x10\x43hangeRobotSpeed\x12\x12.robotc.RobotSpeed\x1a\x0e.robotc.SimResb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,messages__pb2.DESCRIPTOR,])




_SIMRES = _descriptor.Descriptor(
  name='SimRes',
  full_name='robotc.SimRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='robotc.SimRes.ret', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=94,
)


_BUTTONREQ = _descriptor.Descriptor(
  name='ButtonReq',
  full_name='robotc.ButtonReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ButtonReq.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='robotc.ButtonReq.state', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=134,
)


_DIALGAGEREQ = _descriptor.Descriptor(
  name='DialgageReq',
  full_name='robotc.DialgageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.DialgageReq.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.DialgageReq.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=176,
)


_ROBOTSPEED = _descriptor.Descriptor(
  name='RobotSpeed',
  full_name='robotc.RobotSpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cycle', full_name='robotc.RobotSpeed.cycle', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=205,
)

DESCRIPTOR.message_types_by_name['SimRes'] = _SIMRES
DESCRIPTOR.message_types_by_name['ButtonReq'] = _BUTTONREQ
DESCRIPTOR.message_types_by_name['DialgageReq'] = _DIALGAGEREQ
DESCRIPTOR.message_types_by_name['RobotSpeed'] = _ROBOTSPEED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimRes = _reflection.GeneratedProtocolMessageType('SimRes', (_message.Message,), {
  'DESCRIPTOR' : _SIMRES,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SimRes)
  })
_sym_db.RegisterMessage(SimRes)

ButtonReq = _reflection.GeneratedProtocolMessageType('ButtonReq', (_message.Message,), {
  'DESCRIPTOR' : _BUTTONREQ,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ButtonReq)
  })
_sym_db.RegisterMessage(ButtonReq)

DialgageReq = _reflection.GeneratedProtocolMessageType('DialgageReq', (_message.Message,), {
  'DESCRIPTOR' : _DIALGAGEREQ,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DialgageReq)
  })
_sym_db.RegisterMessage(DialgageReq)

RobotSpeed = _reflection.GeneratedProtocolMessageType('RobotSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTSPEED,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotSpeed)
  })
_sym_db.RegisterMessage(RobotSpeed)



_SIMULATIONCONTROLLER = _descriptor.ServiceDescriptor(
  name='SimulationController',
  full_name='robotc.SimulationController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=208,
  serialized_end=659,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetPos',
    full_name='robotc.SimulationController.SetPos',
    index=0,
    containing_service=None,
    input_type=messages__pb2._JPOSE,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EStop',
    full_name='robotc.SimulationController.EStop',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EStopRelease',
    full_name='robotc.SimulationController.EStopRelease',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Button',
    full_name='robotc.SimulationController.Button',
    index=3,
    containing_service=None,
    input_type=_BUTTONREQ,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDialgage',
    full_name='robotc.SimulationController.SetDialgage',
    index=4,
    containing_service=None,
    input_type=_DIALGAGEREQ,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRobotAI',
    full_name='robotc.SimulationController.SetRobotAI',
    index=5,
    containing_service=None,
    input_type=messages__pb2._AIO,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRobotDI',
    full_name='robotc.SimulationController.SetRobotDI',
    index=6,
    containing_service=None,
    input_type=messages__pb2._DIO,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFlangeDI',
    full_name='robotc.SimulationController.SetFlangeDI',
    index=7,
    containing_service=None,
    input_type=messages__pb2._DIO,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeRobotSpeed',
    full_name='robotc.SimulationController.ChangeRobotSpeed',
    index=8,
    containing_service=None,
    input_type=_ROBOTSPEED,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIMULATIONCONTROLLER)

DESCRIPTOR.services_by_name['SimulationController'] = _SIMULATIONCONTROLLER

# @@protoc_insertion_point(module_scope)



# Copyright (C) 2017-2021 Lebai Robotics
# Author: kingfree
# Contact: kingfree@toyama.moe

"""Lebai Robot Python SDK"""

from .type import RobotState, TaskStatus, IODeviceType, CartesianPose, JointPose, Error, RequestError
from .robot import LebaiRobot
from .scene import LebaiScene
